@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: language-javascript
-version: 0.5.14.2
-id: language-javascript-0.5.14.2-f55c8cd80a337ed6a6cb1df128d3b4c5
-key: langu_BhFaTT7igFaCeyrexEX89r
+version: 0.6.0.2
+id: language-javascript-0.6.0.2-b872ffab7eb92e354d2028cc73df3cc6
+key: langu_5nB0ZsQBMbm3QySActzoYe
 license: BSD3
 copyright: (c) 2010-2015 Alan Zimmerman, 2015 Erik de Castro Lopo
 maintainer: Erik de Castro Lopo <erikd@mega-nerd.com>
@@ -18,28 +18,30 @@ category: Language
 author: Alan Zimmerman
 exposed: True
 exposed-modules:
-    Language.JavaScript.Parser Language.JavaScript.Parser.Parser
-    Language.JavaScript.Parser.Lexer
-    Language.JavaScript.Parser.Grammar5 Language.JavaScript.Parser.AST
-    Language.JavaScript.Pretty.Printer
+    Language.JavaScript.Parser Language.JavaScript.Parser.AST
+    Language.JavaScript.Parser.Grammar5
+    Language.JavaScript.Parser.Lexer Language.JavaScript.Parser.Parser
     Language.JavaScript.Parser.SrcLocation
+    Language.JavaScript.Pretty.Printer
+    Language.JavaScript.Process.Minify
 hidden-modules: Language.JavaScript.Parser.LexerUtils
                 Language.JavaScript.Parser.ParseError
                 Language.JavaScript.Parser.ParserMonad
                 Language.JavaScript.Parser.StringEscape
                 Language.JavaScript.Parser.Token
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/language-javascript-0.5.14.2
-library-dirs: /usr/lib/ghc-7.10.3/site-local/language-javascript-0.5.14.2
-data-dir: /usr/share/arm-linux-ghc-7.10.3/language-javascript-0.5.14.2
-hs-libraries: HSlanguage-javascript-0.5.14.2-BhFaTT7igFaCeyrexEX89r
+import-dirs: /usr/lib/ghc-7.10.3/site-local/language-javascript-0.6.0.2
+library-dirs: /usr/lib/ghc-7.10.3/site-local/language-javascript-0.6.0.2
+data-dir: /usr/share/arm-linux-ghc-7.10.3/language-javascript-0.6.0.2
+hs-libraries: HSlanguage-javascript-0.6.0.2-5nB0ZsQBMbm3QySActzoYe
 depends:
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
+    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
+    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     utf8-string-1.0.1.1-55be01444fdc59e978af349d80596373
 haddock-interfaces: /usr/share/doc/haskell-language-javascript/html/language-javascript.haddock
 haddock-html: /usr/share/doc/haskell-language-javascript/html
